@@ -150,35 +150,21 @@ class FrescoApp(RouteCollection):
 
     def get_response(
         self,
-        routecollection=None,
-        request=None,
-        path=None,
-        method=None,
+        request,
+        path,
+        method,
         currentcontext=context.currentcontext,
         normpath=normpath,
     ):
-
         ctx = currentcontext()
-        try:
-            routecollection = routecollection or self
-            request = request or ctx["request"]
-            method = method or request.method
-            path = path or request.path_info
-            error_response = None
+        ctx["app"] = self
+        environ = request.environ
+        environ["fresco.app"] = self
+        error_response = response = None
 
-            ctx["app"] = self
-            environ = request.environ
-            environ["fresco.app"] = self
+        if ".." in path or "//" in path or "/./" in path:
+            path = normpath(path)
 
-            if path:
-                if ".." in path or "//" in path or "/./" in path:
-                    path = normpath(path)
-            else:
-                path = "/"
-        except ResponseException as e:
-            return e.response
-
-        response = None
         for f in self.process_request_handlers:
             try:
                 r = f(request)
@@ -190,7 +176,7 @@ class FrescoApp(RouteCollection):
             return response
 
         try:
-            for traversal in routecollection.get_routes(path, method, request):
+            for traversal in self.get_route_traversals(path, method, request):
                 try:
                     route = traversal.route
                     environ["wsgiorg.routing_args"] = (
@@ -228,6 +214,7 @@ class FrescoApp(RouteCollection):
                         route.fallthrough_statuses
                         and response.status_code in route.fallthrough_statuses
                     ):
+                        error_response = response
                         continue
 
                 except ResponseException as e:
@@ -259,26 +246,35 @@ class FrescoApp(RouteCollection):
 
         # Is this a head request?
         if method == "HEAD":
-            response = self.get_response(routecollection, request, path, GET)
+            response = self.get_response(request, path, GET)
             if "200" <= response.status < "300":
                 return response.replace(content=[], content_length=0)
             return response
 
         # Is the URL matched by another HTTP method?
-        methods = self.get_methods(routecollection, request, path)
+        methods = self.get_methods(request, path)
         if methods:
             return Response.method_not_allowed(methods)
 
         # Is the URL just missing a trailing '/'?
-        if path[-1] != "/":
-            for _ in self.get_methods(routecollection, request, path + "/"):
+        if not path or path[-1] != "/":
+            for _ in self.get_methods(request, path + "/"):
                 return Response.unrestricted_redirect_permanent(path + "/")
 
         return Response.not_found()
 
     def view(self, request=None) -> Response:
         request = request or context.request
-        response = self.get_response(request=request)
+        try:
+            path = request.path_info
+        except ResponseException as e:
+            response = e.response
+        else:
+            response = self.get_response(
+                request,
+                path,
+                request.method
+            )
 
         for f in self.process_response_handlers:
             try:
@@ -310,12 +306,12 @@ class FrescoApp(RouteCollection):
                 self.log_exception(request)
         return response
 
-    def get_methods(self, routecollection, request, path):
+    def get_methods(self, request, path):
         """\
         Return the HTTP methods valid in routes to the given path
         """
         methods: Set[str] = set()
-        for traversal in routecollection.get_routes(path, None):
+        for traversal in self.get_route_traversals(path, None):
             route = traversal.route
             if route.predicate and not route.predicate(request):
                 continue
@@ -510,11 +506,12 @@ class FrescoApp(RouteCollection):
         All other arguments or keyword args are fed to the ``pathfor`` method
         of the pattern.
         """
-        scheme = kwargs.pop("_scheme", None)
-        netloc = kwargs.pop("_netloc", None)
-        query = kwargs.pop("_query", {})
-        script_name = kwargs.pop("_script_name", None)
-        fragment = kwargs.pop("_fragment", None)
+        popkw = kwargs.pop
+        scheme = popkw("_scheme", None)
+        netloc = popkw("_netloc", None)
+        query = popkw("_query", {})
+        script_name = popkw("_script_name", None)
+        fragment = popkw("_fragment", None)
 
         ctx = context.currentcontext()
         request = ctx["request"]
@@ -629,7 +626,7 @@ class FrescoApp(RouteCollection):
 
             >>> app = FrescoApp()
             >>> with app.requestcontext('http://www.example.com/view') as c:
-            ...     print c.request.url
+            ...     print(c.request.url)
             ...
             http://www.example.com/view
 
