@@ -12,54 +12,7 @@
 #     See the License for the specific language governing permissions and
 #     limitations under the License.
 #
-
-import sys
-from fresco import context
-
-__all__ = 'FrescoCoreMiddleware', 'XForwarded'
-
-
-class FrescoCoreMiddleware(object):
-
-    def __init__(self, wsgiapp, frescoapp):
-        self.wsgiapp = wsgiapp
-        self.frescoapp = frescoapp
-
-    def __call__(self, environ, start_response):
-
-        request = self.frescoapp.request_class(environ)
-        context.push(request=request, app=self.frescoapp)
-        iterator = None
-        try:
-            iterator = self.wsgiapp(environ, start_response)
-            for item in iterator:
-                yield item
-        except Exception:
-            exc_info = sys.exc_info()
-            request = context.request
-            try:
-                response = self.frescoapp.handle_exception(request)
-                if '400' <= response.status <= '599':
-                    response = self.frescoapp.handle_http_error_response(
-                        request, response)
-
-                exc_start_response = lambda s, h, exc_info=exc_info: \
-                        start_response(s, h, exc_info)
-                for item in response(environ, exc_start_response):
-                    yield item
-            finally:
-                del exc_info
-        finally:
-            try:
-                if self.frescoapp.process_teardown_handlers:
-                    self.frescoapp.call_process_teardown_handlers(request)
-            finally:
-                try:
-                    close = getattr(iterator, 'close', None)
-                    if close is not None:
-                        close()
-                finally:
-                    context.pop()
+__all__ = "XForwarded"
 
 
 class XForwarded(object):
@@ -126,26 +79,31 @@ class XForwarded(object):
         """\
         Call the WSGI app, passing it a modified environ
         """
-        is_ssl = environ.get('HTTP_X_FORWARDED_SSL') == 'on'
+        env = environ.get
+        is_ssl = (
+            env("HTTP_X_FORWARDED_PROTO") == "https"
+            or env("HTTP_X_FORWARDED_SSL") == "on"
+        )
 
-        if 'HTTP_X_FORWARDED_HOST' in environ:
-            host = environ['HTTP_X_FORWARDED_HOST']
-
-            if ':' in host:
-                port = host.split(':')[1]
+        host = env("HTTP_X_FORWARDED_HOST")
+        if host is not None:
+            if ":" in host:
+                port = host.split(":")[1]
             else:
-                port = is_ssl and '443' or '80'
+                port = is_ssl and "443" or "80"
 
-            environ['HTTP_HOST'] = host
-            environ['SERVER_PORT'] = port
+            environ["HTTP_HOST"] = host
+            environ["SERVER_PORT"] = port
 
         if is_ssl:
-            environ['wsgi.url_scheme'] = 'https'
-            environ['HTTPS'] = 'on'
+            environ["wsgi.url_scheme"] = "https"
+            environ["HTTPS"] = "on"
 
         try:
-            forwards = environ['HTTP_X_FORWARDED_FOR'].split(', ')\
-                       + [environ.get('REMOTE_ADDR', '')]
+
+            forwards = environ["HTTP_X_FORWARDED_FOR"].split(", ") + [
+                env("REMOTE_ADDR", "")
+            ]
         except KeyError:
             # No X-Forwarded-For header?
             return self.app(environ, start_response)
@@ -154,9 +112,9 @@ class XForwarded(object):
             for ip in forwards[::-1]:
                 # Find the first non-trusted ip; this is our remote address
                 if ip not in self.trusted:
-                    environ['REMOTE_ADDR'] = ip
+                    environ["REMOTE_ADDR"] = ip
                     break
         else:
-            environ['REMOTE_ADDR'] = forwards[0]
+            environ["REMOTE_ADDR"] = forwards[0]
 
         return self.app(environ, start_response)
