@@ -49,7 +49,10 @@ class Options(dict):
         self.__dict__["_loaded_callbacks"] = []
 
     def __getattr__(self, name):
-        return self[name]
+        try:
+            return self[name]
+        except KeyError:
+            raise AttributeError(name)
 
     def __setattr__(self, key, value):
         self[key] = value
