@@ -352,9 +352,7 @@ class Request(object):
         """\
         Return the path component of the requested URL
         """
-        return environ_to_str(
-            self.environ.get("SCRIPT_NAME", "") + self.environ.get("PATH_INFO", "")
-        )
+        return environ_to_str(self.environ["SCRIPT_NAME"] + self.environ["PATH_INFO"])
 
     @property
     def url(self):
@@ -384,7 +382,7 @@ class Request(object):
             (
                 scheme,
                 netloc,
-                quote(self.script_name.encode(self.charset)),
+                quote(self.environ["SCRIPT_NAME"], encoding="latin1"),
                 "",
                 "",
                 "",
@@ -413,14 +411,14 @@ class Request(object):
         if self._parsed_url:
             return self._parsed_url
 
-        env = self.environ.get
-        script_name = quote(self.script_name.encode(self.charset))
-        path_info = quote(self.path_info.encode(self.charset))
+        environ = self.environ
+        script_name = quote(self.environ["SCRIPT_NAME"], encoding="latin1")
+        path_info = quote(self.environ["PATH_INFO"], encoding="latin1")
         query_string = self.query_string
-        scheme = environ_to_str(env("wsgi.url_scheme", "http"))
+        scheme = environ["wsgi.url_scheme"]
 
         try:
-            host = environ_to_str(self.environ["HTTP_HOST"])
+            host = environ["HTTP_HOST"]
             if ":" in host:
                 host, port = host.split(":", 1)
             else:
@@ -429,8 +427,8 @@ class Request(object):
                 else:
                     port = "80"
         except KeyError:
-            host = environ_to_str(self.environ["SERVER_NAME"])
-            port = environ_to_str(self.environ["SERVER_PORT"])
+            host = environ["SERVER_NAME"]
+            port = environ["SERVER_PORT"]
 
         if (scheme == "http" and port == "80") or (scheme == "https" and port == "443"):
             netloc = host
@@ -455,7 +453,7 @@ class Request(object):
         Note that PATH_INFO is already unquoted by the server
         """
         try:
-            return environ_to_str(self.environ.get("PATH_INFO", ""), self.charset)
+            return environ_to_str(self.environ["PATH_INFO"], self.charset)
         except UnicodeDecodeError:
             raise exceptions.BadRequest
 
@@ -467,22 +465,16 @@ class Request(object):
         Note that SCRIPT_NAME is already unquoted by the server
         """
         try:
-            return environ_to_str(self.environ.get("SCRIPT_NAME", ""), self.charset)
+            return environ_to_str(self.environ["SCRIPT_NAME"], self.charset)
         except UnicodeDecodeError:
             raise exceptions.BadRequest
 
     @property
-    def query_string(  # type: ignore
-        self,
-        environ_to_str=environ_to_str,
-    ) -> Optional[str]:
-        """\
+    def query_string(self) -> Optional[str]:
+        """
         The QUERY_STRING value as a unicode string
         """
-        s = self.environ.get("QUERY_STRING")
-        if s is None:
-            return s
-        return environ_to_str(s)
+        return self.environ.get("QUERY_STRING")
 
     @property
     def referrer(self):
@@ -645,7 +637,7 @@ class Request(object):
         parsed_url = self.parsed_url
 
         if path is not None:
-            path = quote(path)
+            path = quote(path, encoding=self.charset)
 
             if path[0] != "/":
                 path = posixpath.join(posixpath.dirname(parsed_url[2]), path)
@@ -656,7 +648,7 @@ class Request(object):
                 SCRIPT_NAME = self.script_name
             if PATH_INFO is None:
                 PATH_INFO = self.path_info
-            path = quote(SCRIPT_NAME + PATH_INFO)
+            path = quote(SCRIPT_NAME + PATH_INFO, encoding=self.charset)
 
         else:
             path = parsed_url[2]
@@ -745,15 +737,16 @@ class Request(object):
 
         If not specified, application relative paths will be assumed.
         """
-        env = self.environ.get
+        environ = self.environ
+        env = environ.get
 
         if "://" not in url:
-            scheme = env("wsgi.url_scheme", "http")
+            scheme = environ["wsgi.url_scheme"]
 
             if scheme == "https":
-                port = ":" + env("SERVER_PORT", "443")
+                port = ":" + environ["SERVER_PORT"]
             else:
-                port = ":" + env("SERVER_PORT", "80")
+                port = ":" + environ["SERVER_PORT"]
 
             if (
                 scheme == "http"
@@ -764,23 +757,22 @@ class Request(object):
                 port = ""
 
             parsed = urlparse(url)
-            path_info = env("PATH_INFO", "")
-            script_name = env("SCRIPT_NAME", "")
+            path_info = quote(environ["PATH_INFO"].encode("latin-1"))
+            script_name = quote(environ["SCRIPT_NAME"].encode("latin-1"))
 
-            if path_info[-1] != "/":
+            if not path_info or path_info[-1] != "/":
                 path_info = path_info[: path_info.rfind("/") + 1]
 
             if relative == "app":
-                path = posixpath.join(quote(path_info), parsed[2])
-                path = quote(script_name) + normpath(path)
+                path = script_name + normpath(posixpath.join(path_info, parsed[2]))
 
             else:
-                path = posixpath.join(quote(script_name) + path_info, parsed[2])
+                path = posixpath.join(script_name + path_info, parsed[2])
 
             url = urlunparse(
                 (
-                    env("wsgi.url_scheme", ""),
-                    env("HTTP_HOST", env("SERVER_NAME", "") + port),
+                    scheme,
+                    env("HTTP_HOST", environ["SERVER_NAME"] + port),
                     normpath(path),
                     parsed[3],
                     parsed[4],
