@@ -14,10 +14,10 @@
 #
 import re
 import sys
+import warnings
 from copy import copy
 from collections import defaultdict
 from collections import namedtuple
-from collections.abc import Iterable
 from collections.abc import MutableSequence
 from importlib import import_module
 from functools import partial
@@ -25,6 +25,8 @@ from typing import Any
 from typing import Callable
 from typing import Dict
 from typing import List
+from typing import Iterator
+from typing import Iterable
 from typing import Mapping
 from typing import Optional
 from typing import Union
@@ -34,13 +36,13 @@ from weakref import WeakKeyDictionary
 
 from fresco.exceptions import ResponseException
 from fresco.response import Response
+from fresco.request import Request
 from fresco.requestcontext import context
 from fresco.routeargs import RouteArg
 from fresco.util.cache import make_cache
 from fresco.util.common import fq_path
 from fresco.util.urls import join_path
 from fresco.util.object import classorinstancemethod
-from fresco.util.wsgi import getenv, setenv
 
 RFC2518_METHODS = PROPFIND, PROPPATCH, MKCOL, COPY, MOVE, LOCK, UNLOCK = (
     "PROPFIND",
@@ -158,7 +160,7 @@ class RouteTraversal(
             ... def homepage(lang):
             ...     return Response({'fr': 'Bonjour!', 'en': 'Hello!'}[lang])
             ...
-            >>> traversal = next(app.get_routes('/fr/index.html'))
+            >>> traversal = next(app.get_route_traversals('/fr/index.html'))
             >>> en_traversal = traversal.replace('home', {'lang': 'en'})
             >>> en_traversal.build_path()
             '/en/index.html'
@@ -484,9 +486,7 @@ class ExtensiblePattern(Pattern):
         self.match_entire_path = match_entire_path
 
         self.segments = list(self._make_segments())
-        self.args = [
-            item for item in self.segments if item.converter is not None
-        ]
+        self.args = [item for item in self.segments if item.converter is not None]
 
         regex = "".join(segment.regex for segment in self.segments)
         if self.match_entire_path:
@@ -610,17 +610,14 @@ class ExtensiblePattern(Pattern):
                     value = arg_list.pop(0)
                 except IndexError:
                     raise URLGenerationError(
-                        "Not enough positional arguments for url %r"
-                        % (self.pattern,)
+                        "Not enough positional arguments for url %r" % (self.pattern,)
                     )
                 result_append(seg.converter.to_string(value))
 
         return "".join(result), arg_list, kwargs
 
     def add_prefix(self, prefix):
-        return self.__class__(
-            join_path(prefix, self.pattern), self.match_entire_path
-        )
+        return self.__class__(join_path(prefix, self.pattern), self.match_entire_path)
 
     @classmethod
     def register_converter(cls, name, converter):
@@ -696,6 +693,7 @@ class Route(object):
         decorators=None,
         filters=None,
         fallthrough_on=None,
+        provide_request: Optional[bool] = None,
         **_kwargs,
     ):
 
@@ -720,6 +718,8 @@ class Route(object):
                                by a view will cause the current response to be
                                discarded with routing continuing to the next
                                available route.
+        :param provide_request: If True, provide the current request as the
+                                first argument to the view callable.
         :param **_kwargs:   Keyword arguments matching HTTP method names
                             (GET, POST etc) can used to specify views
                             associated with those methods.
@@ -774,14 +774,11 @@ class Route(object):
                 # Catch the common error of not providing a valid method
                 if not isinstance(methods, Iterable):
                     raise TypeError(
-                        "HTTP methods must be specified as a "
-                        "string or iterable"
+                        "HTTP methods must be specified as a string or iterable"
                     )
             for m in methods:
                 if m not in ALL_METHODS:
-                    raise ValueError(
-                        "{!r} is not a valid HTTP method".format(m)
-                    )
+                    raise ValueError("{!r} is not a valid HTTP method".format(m))
             method_view_map.update((m, view) for m in methods)
 
         for method in ALL_METHODS:
@@ -805,6 +802,9 @@ class Route(object):
         else:
             self.fallthrough_statuses = None
 
+        if provide_request is not None:
+            self.provide_request = provide_request
+
         #: Default values to use for path generation
         self.routed_args_default: Dict[str, Any] = {}
 
@@ -827,9 +827,7 @@ class Route(object):
                 self.routed_args_default[k] = default
 
         self.view_args = tuple(args or _kwargs.pop("view_args", tuple()))
-        self.view_kwargs = dict(
-            kwargs or _kwargs.pop("view_kwargs", {}), **_kwargs
-        )
+        self.view_kwargs = dict(kwargs or _kwargs.pop("view_kwargs", {}), **_kwargs)
 
         for arg in self.view_args:
             if isinstance(arg, RouteArg):
@@ -856,10 +854,7 @@ class Route(object):
                 method_str = "*"
             else:
                 method_str = " ".join(self.methods)
-            s.append(
-                "%s %s => %r"
-                % (method_str, str(self.pattern), fq_path(viewspec))
-            )
+            s.append("%s %s => %r" % (method_str, str(self.pattern), fq_path(viewspec)))
 
         return "<%s %s>" % (self.__class__.__name__, "\n      ".join(s))
 
@@ -994,9 +989,7 @@ class Route(object):
         routing pattern.
         """
         newroute = object.__new__(self.__class__)
-        newroute.__dict__ = dict(
-            self.__dict__, pattern=self.pattern.add_prefix(path)
-        )
+        newroute.__dict__ = dict(self.__dict__, pattern=self.pattern.add_prefix(path))
         return newroute
 
     def path(self, *args, **kwargs):
@@ -1132,6 +1125,7 @@ class RRoute(Route):
     A subclass of :class:`fresco.routing.Route` that always provides an initial
     `request` argument to the view.
     """
+
     provide_request = True
 
 
@@ -1284,9 +1278,7 @@ class RouteCollection(MutableSequence):
             viewspec, remainder = viewspec.split(":", 1)
             delegated_route = self.routefor(viewspec)
 
-            p1, remainder_args, remainder_kwargs = delegated_route.path(
-                *args, **kwargs
-            )
+            p1, remainder_args, remainder_kwargs = delegated_route.path(*args, **kwargs)
 
             factory_args = args[: -len(remainder_args)]
             factory_kwargs = {
@@ -1364,9 +1356,7 @@ class RouteCollection(MutableSequence):
                         raise route_or_rnf
                     return route_or_rnf
                 else:
-                    exc = self.__routed_views__[viewspec] = RouteNotFound(
-                        viewspec
-                    )
+                    exc = self.__routed_views__[viewspec] = RouteNotFound(viewspec)
                     raise exc
 
     def _get_routes(self, key):
@@ -1374,11 +1364,14 @@ class RouteCollection(MutableSequence):
         routes = ((r, r.match(path, method)) for r in self.__routes__)
         return [(r, t) for (r, t) in routes if t is not None]
 
-    def get_routes(self, path, method, request=None):
+    def get_route_traversals(
+        self, path: str, method: Optional[str], request: Optional[Request] = None
+    ) -> Iterator[RouteTraversal]:
         """
-        Generate routes matching the given path and method::
+        Generate RouteTraversals for routes matching the given path and
+        method::
 
-            for rt in routecollection.get_routes('/foo/bar', GET):
+            for rt in routecollection.get_route_traversals('/foo/bar', GET):
                 print("Route is", rt.route)
                 print("Arguments extracted from the path:", rt.args, rt.kwargs)
                 print("RouteCollections are:", rt.collections_traversed)
@@ -1439,7 +1432,7 @@ class RouteCollection(MutableSequence):
                     yield RouteTraversal(r, (), {}, [(self, "", r)])
                     continue
 
-                for sub in sub_routes.get_routes(
+                for sub in sub_routes.get_route_traversals(
                     result.path_remaining, method, request
                 ):
                     traversed = [
@@ -1454,18 +1447,14 @@ class RouteCollection(MutableSequence):
                         )
                     ]
                     traversed.extend(
-                        TraversedCollection(
-                            c, result.path_matched + p, r, a, k, ta, tk
-                        )
+                        TraversedCollection(c, result.path_matched + p, r, a, k, ta, tk)
                         for c, p, r, a, k, ta, tk in sub.collections_traversed
                     )
 
                     # Dynamic routes consume their arguments when creating the
                     # sub RouteCollection.
                     if route.dynamic:
-                        yield RouteTraversal(
-                            sub.route, sub.args, sub.kwargs, traversed
-                        )
+                        yield RouteTraversal(sub.route, sub.args, sub.kwargs, traversed)
                     else:
                         yield RouteTraversal(
                             sub.route,
@@ -1491,6 +1480,16 @@ class RouteCollection(MutableSequence):
                     ],
                 )
 
+    def get_routes(
+        self, path: str, method: str, request: Optional[Request] = None
+    ) -> Iterable[RouteTraversal]:
+        warnings.warn(
+            "RouteCollection.get_routes is deprecated and will be removed "
+            "in a future version. Use get_route_traversals instead",
+            DeprecationWarning,
+        )
+        return self.get_route_traversals(path, method, request)
+
     def route(self, pattern, methods=None, view=None, *args, **kwargs):
         """
         Match a URL pattern to a view function. Can be used as a function
@@ -1505,9 +1504,7 @@ class RouteCollection(MutableSequence):
         """
         # Catch the common error of not providing a valid method
         if methods and not isinstance(methods, Iterable):
-            raise TypeError(
-                "HTTP methods must be specified as a string or iterable"
-            )
+            raise TypeError("HTTP methods must be specified as a string or iterable")
 
         # Called as a decorator?
         if methods is not None and view is None:
@@ -1524,9 +1521,7 @@ class RouteCollection(MutableSequence):
         self.add_route(route)
         return route
 
-    def route_wsgi(
-        self, path, wsgiapp, rewrite_script_name=True, *args, **kwargs
-    ):
+    def route_wsgi(self, path, wsgiapp, rewrite_script_name=True, *args, **kwargs):
         """
         Route requests to ``path`` to the given WSGI application
 
@@ -1538,35 +1533,38 @@ class RouteCollection(MutableSequence):
                                     ``SCRIPT_NAME`` environ key.
         """
 
-        def fresco_wsgi_view(
-            path=path, rewrite_script_name=rewrite_script_name
-        ):
-            def fake_start_response(status, headers, exc_info=None):
-                return None
+        def fake_start_response(status, headers, exc_info=None):
+            return None
 
+        if path.encode("ascii", "ignore").decode("ascii") == path:
+            ws_path = path
+        else:
+            ws_path = None
+
+        def fresco_wsgi_view(
+            path=path,
+            ws_path=ws_path,
+            context=context,
+            rewrite_script_name=rewrite_script_name,
+            fake_start_response=fake_start_response,
+            make_response=Response.from_wsgi,
+            wsgiapp=wsgiapp,
+        ):
             request = context.request
             environ = request.environ
-            preserve_script_name = not rewrite_script_name or (
-                path == "/" and environ["SCRIPT_NAME"] == ""
+            ws_SCRIPT_NAME = environ["SCRIPT_NAME"]
+            shift_script_name = rewrite_script_name and not (
+                path == "/" and ws_SCRIPT_NAME == ""
             )
-            if not preserve_script_name:
-                path = path.encode(request.charset)
+            if shift_script_name:
+                if ws_path is None:
+                    ws_path = path.encode(request.charset).decode("ISO-8859-1")
                 environ = environ.copy()
-                setenv(
-                    environ,
-                    "SCRIPT_NAME",
-                    (getenv(environ, "SCRIPT_NAME", b"") + path),
-                )
-                setenv(
-                    environ,
-                    "PATH_INFO",
-                    (getenv(environ, "PATH_INFO", b"")[len(path) :]),
-                )
-            return Response.from_wsgi(wsgiapp, environ, fake_start_response)
+                environ["SCRIPT_NAME"] = ws_SCRIPT_NAME + ws_path
+                environ["PATH_INFO"] = environ["PATH_INFO"][len(ws_path) :]
+            return make_response(wsgiapp, environ, fake_start_response)
 
-        return self.route_all(
-            path, ALL_METHODS, fresco_wsgi_view, *args, **kwargs
-        )
+        return self.route_all(path, ALL_METHODS, fresco_wsgi_view, *args, **kwargs)
 
     def route_all(self, path, *args, **kwargs):
         """\
@@ -1657,13 +1655,10 @@ class DelegateRoute(Route):
             self.routecollectionfactory = self._static_routecollectionfactory
             if not isinstance(view, RouteCollection):
                 routes = [
-                    r.bindto(view) if r.instance is None else r
-                    for r in view.__routes__
+                    r.bindto(view) if r.instance is None else r for r in view.__routes__
                 ]
                 view = RouteCollection(routes)
-        super(DelegateRoute, self).__init__(
-            pattern, ALL_METHODS, view, *args, **kwargs
-        )
+        super(DelegateRoute, self).__init__(pattern, ALL_METHODS, view, *args, **kwargs)
 
     def _dynamic_routecollectionfactory(self, *args, **kwargs):
         """\
