@@ -14,7 +14,7 @@
 #
 from wsgiref.util import setup_testing_defaults
 
-from mock import Mock, call
+from unittest.mock import Mock, call
 import pytest
 
 from fresco import Request, Response
@@ -196,10 +196,10 @@ class TestFrescoApp(object):
         app.route("/2", DELETE, lambda: None)
 
         with app.requestcontext() as c:
-            assert app.get_methods(app, c.request, "/1") == set([POST, PUT])
+            assert app.get_methods(c.request, "/1") == set([POST, PUT])
 
         with app.requestcontext() as c:
-            assert app.get_methods(app, c.request, "/2") == set([GET, DELETE])
+            assert app.get_methods(c.request, "/2") == set([GET, DELETE])
 
     def test_get_methods_matches_on_predicate(self):
 
@@ -211,7 +211,7 @@ class TestFrescoApp(object):
         app.route("/", PUT, lambda: None, predicate=p2)
 
         with app.requestcontext("/") as c:
-            assert app.get_methods(app, c.request, "/") == set([POST])
+            assert app.get_methods(c.request, "/") == set([POST])
             assert p1.call_args_list == [call(c.request)]
             assert p2.call_args_list == [call(c.request)]
 
@@ -272,6 +272,14 @@ class TestFrescoApp(object):
 
         assert response.status_code == 200
 
+    def test_fallthrough_on_returns_last_error(self):
+        app = FrescoApp()
+        app.route("/", GET=lambda: Response(status="499"), fallthrough_on={499})
+
+        with app.requestcontext("/"):
+            response = app.view()
+        assert response.status_code == 499
+
 
 class TestAppHooks(object):
     def test_process_request_continues_on_none(self):
@@ -703,11 +711,16 @@ class TestTrailingSlashes(object):
 
         app = FrescoApp()
         app.route("/foo/", GET, foo)
+        app.route("/", GET, foo)
 
         with app.requestcontext("/foo"):
             assert app.view().status_code == 301
             assert app.view().get_header("location") == "http://localhost/foo/"
 
+        with app.requestcontext(""):
+            assert app.view().status_code == 301
+            assert app.view().get_header("location") == "http://localhost/"
+
 
 class TestViewCollection(object):
     def test_appdef(self):
@@ -1047,5 +1060,5 @@ class TestUrlfor(object):
             assert urlfor(f, _query={"a": "1"}) == "http://localhost/?a=1"
             assert (
                 urlfor(f, _query=[("a", "1"), ("a", 2)])
-                == "http://localhost/?a=1;a=2"
+                == "http://localhost/?a=1&a=2"
             )
