@@ -254,14 +254,14 @@ class TestMakeURL(object):
         with context() as c:
             self.assert_equal_with_query(
                 c.request.make_url(query={"a": 1, "b": "2 3"}),
-                "http://localhost/?a=1;b=2+3",
+                "http://localhost/?a=1&b=2+3",
             )
 
     def test_query_kwargs(self):
         with context() as c:
             self.assert_equal_with_query(
                 c.request.make_url(query={"a": 1}, b=2),
-                "http://localhost/?a=1;b=2",
+                "http://localhost/?a=1&b=2",
             )
 
     def test_unicode_path(self):
@@ -293,14 +293,14 @@ class TestMakeURL(object):
         with context(QUERY_STRING="a=1") as c:
             self.assert_equal_with_query(
                 c.request.make_url(query_replace={"b": "2"}),
-                "http://localhost/?a=1;b=2",
+                "http://localhost/?a=1&b=2",
             )
 
     def test_add_query_doesnt_replace_existing(self):
         with context(QUERY_STRING="a=1") as c:
             self.assert_equal_with_query(
                 c.request.make_url(query_add={"a": "2"}),
-                "http://localhost/?a=1;a=2",
+                "http://localhost/?a=1&a=2",
             )
 
     def test_add_query_works_on_specified_query(self):
