@@ -12,7 +12,7 @@
 #     See the License for the specific language governing permissions and
 #     limitations under the License.
 #
-from mock import Mock, call
+from unittest.mock import Mock, call
 
 from fresco import routeargs
 from fresco.core import FrescoApp
@@ -92,6 +92,12 @@ class TestRouteArg(object):
             app.view()
             assert view.call_args_list == [call(x=0.0)]
 
+    def test_it_converts_lists(self):
+        arg = routeargs.RequestArg(converter=[str])
+        arg.configure(None, "foo")
+        with FrescoApp().requestcontext("/?foo=a&foo=b") as r:
+            assert arg(r.request) == ["a", "b"]
+
     def test_requestarg_default_value(self):
         view = Mock(return_value=Response())
         app = FrescoApp()
