@@ -16,7 +16,7 @@
 from copy import copy
 from functools import wraps
 
-from mock import Mock, call
+from unittest.mock import Mock, call
 import pytest
 import tms
 
@@ -379,8 +379,8 @@ class TestRouteCollection(object):
 
         rc = RouteCollection([r_post, r_get])
 
-        assert [r.route for r in rc.get_routes("/", GET)] == [r_get]
-        assert [r.route for r in rc.get_routes("/", POST)] == [r_post]
+        assert [r.route for r in rc.get_route_traversals("/", GET)] == [r_get]
+        assert [r.route for r in rc.get_route_traversals("/", POST)] == [r_post]
 
     def test_get_routes_matches_on_path(self):
 
@@ -389,8 +389,8 @@ class TestRouteCollection(object):
 
         rc = RouteCollection([r1, r2])
 
-        assert [r.route for r in rc.get_routes("/1", GET)] == [r1]
-        assert [r.route for r in rc.get_routes("/2", GET)] == [r2]
+        assert [r.route for r in rc.get_route_traversals("/1", GET)] == [r1]
+        assert [r.route for r in rc.get_route_traversals("/2", GET)] == [r2]
 
     def test_get_routes_can_match_all_methods(self):
 
@@ -398,7 +398,10 @@ class TestRouteCollection(object):
         r2 = Route("/1", POST, None)
 
         rc = RouteCollection([r1, r2])
-        assert [r.route for r in rc.get_routes("/1", None)] == [r1, r2]
+        assert [r.route for r in rc.get_route_traversals("/1", None)] == [
+            r1,
+            r2,
+        ]
 
     def test_route_returns_traversal_information_on_nested_routes(self):
 
@@ -417,7 +420,7 @@ class TestRouteCollection(object):
         a.add_route(a_delegate_route)
         b.add_route(b_delegate_route)
 
-        r = next(a.get_routes("/rabbit/hole/rabbit/harvey", None))
+        r = next(a.get_route_traversals("/rabbit/hole/rabbit/harvey", None))
 
         assert r.collections_traversed == [
             (a, "", a_delegate_route, (), {}, (), {}),
@@ -488,7 +491,9 @@ class TestRouteCollection(object):
         v = MyViews()
         app = FrescoApp()
         app.include("/", v)
-        assert [r.route.getview(GET) for r in app.get_routes("/", GET)] == [v.view]
+        assert [r.route.getview(GET) for r in app.get_route_traversals("/", GET)] == [
+            v.view
+        ]
 
     def test_routecollections_in_classes_can_be_manipulated(self):
         class MyViews(object):
@@ -507,7 +512,7 @@ class TestRouteCollection(object):
         v = MyOtherViews()
         app = FrescoApp()
         app.include("/", v)
-        assert [r.route.getview(GET) for r in app.get_routes("/", GET)] == [
+        assert [r.route.getview(GET) for r in app.get_route_traversals("/", GET)] == [
             v.another_view
         ]
 
@@ -522,14 +527,14 @@ class TestRouteCollection(object):
     def test_it_binds_routes_to_an_instance(self):
         views = fixtures.CBV("test")
         rc = RouteCollection([views])
-        view = next(rc.get_routes("/", GET)).route.getview(GET)
+        view = next(rc.get_route_traversals("/", GET)).route.getview(GET)
         assert_method_bound_to(view, views)
 
     def test_it_binds_routes_to_an_instance_via_include(self):
         views = fixtures.CBV("test")
         rc = RouteCollection([])
         rc.include("/", views)
-        view = next(rc.get_routes("/", GET)).route.getview(GET)
+        view = next(rc.get_route_traversals("/", GET)).route.getview(GET)
         assert_method_bound_to(view, views)
 
     def test_including_twice_does_not_rebind_instance(self):
@@ -538,13 +543,13 @@ class TestRouteCollection(object):
         rc.include("/", views)
         rc2 = RouteCollection([])
         rc2.include("/", rc)
-        view = next(rc2.get_routes("/", GET)).route.getview(GET)
+        view = next(rc2.get_route_traversals("/", GET)).route.getview(GET)
         assert_method_bound_to(view, views)
 
     def test_it_binds_routes_via_a_string(self):
         rc = RouteCollection()
         rc.route("/", GET, "fresco.tests.fixtures.module_level_function")
-        view = next(rc.get_routes("/", GET)).route.getview(GET)
+        view = next(rc.get_route_traversals("/", GET)).route.getview(GET)
         assert view is fixtures.module_level_function
 
     def test_it_inserts_route(self):
@@ -883,25 +888,25 @@ class TestRRoute:
 class TestViewArgs(object):
     def test_it_uses_args(self):
         routes = RouteCollection([Route("/", GET, None, args=(1, 2))])
-        assert list(routes.get_routes("/", GET)) == [
+        assert list(routes.get_route_traversals("/", GET)) == [
             tms.InstanceOf(RouteTraversal, args=(1, 2))
         ]
 
     def test_it_uses_view_args(self):
         routes = RouteCollection([Route("/", GET, None, view_args=(1, 2))])
-        assert list(routes.get_routes("/", GET)) == [
+        assert list(routes.get_route_traversals("/", GET)) == [
             tms.InstanceOf(RouteTraversal, args=(1, 2))
         ]
 
     def test_it_appends_args_extracted_from_path(self):
         routes = RouteCollection([Route("/<:int>", GET, None, view_args=(1, 2))])
-        assert list(routes.get_routes("/3", GET)) == [
+        assert list(routes.get_route_traversals("/3", GET)) == [
             tms.InstanceOf(RouteTraversal, args=(1, 2, 3))
         ]
 
     def test_it_keeps_traversal_args_separate(self):
         routes = RouteCollection([Route("/<:int>", GET, None, view_args=(1,))])
-        assert list(routes.get_routes("/2", GET)) == [
+        assert list(routes.get_route_traversals("/2", GET)) == [
             tms.InstanceOf(
                 RouteTraversal,
                 args=(1, 2),
@@ -917,25 +922,25 @@ class TestViewArgs(object):
 class TestViewKwargs(object):
     def test_it_reads_from_route_kwargs(self):
         routes = RouteCollection([Route("/", GET, None, x=1)])
-        assert list(routes.get_routes("/", GET)) == [
+        assert list(routes.get_route_traversals("/", GET)) == [
             tms.InstanceOf(RouteTraversal, kwargs={"x": 1})
         ]
 
     def test_it_reads_from_kwargs(self):
         routes = RouteCollection([Route("/", GET, None, kwargs={"x": 1})])
-        assert list(routes.get_routes("/", GET)) == [
+        assert list(routes.get_route_traversals("/", GET)) == [
             tms.InstanceOf(RouteTraversal, kwargs={"x": 1})
         ]
 
     def test_it_reads_from_view_kwargs(self):
         routes = RouteCollection([Route("/", GET, None, view_kwargs={"x": 1})])
-        assert list(routes.get_routes("/", GET)) == [
+        assert list(routes.get_route_traversals("/", GET)) == [
             tms.InstanceOf(RouteTraversal, kwargs={"x": 1})
         ]
 
     def test_it_keeps_traversal_kwargs_separate(self):
         routes = RouteCollection([Route("/<x:int>", GET, None, view_kwargs={"y": 1})])
-        assert list(routes.get_routes("/2", GET)) == [
+        assert list(routes.get_route_traversals("/2", GET)) == [
             tms.InstanceOf(
                 RouteTraversal,
                 kwargs={"x": 2, "y": 1},
@@ -979,7 +984,7 @@ class TestRouteClassIsPluggable(object):
         routes = RouteCollection(route_class=self.CustomRoute)
         routes.route("/", GET, myview)
 
-        assert list(routes.get_routes("/", GET)) == [
+        assert list(routes.get_route_traversals("/", GET)) == [
             tms.InstanceOf(RouteTraversal, route=tms.InstanceOf(self.CustomRoute))
         ]
 
@@ -991,7 +996,7 @@ class TestRouteClassIsPluggable(object):
         def myview():
             pass
 
-        assert list(routes.get_routes("/", GET)) == [
+        assert list(routes.get_route_traversals("/", GET)) == [
             tms.InstanceOf(RouteTraversal, route=tms.InstanceOf(self.CustomRoute))
         ]
 
@@ -1005,7 +1010,7 @@ class TestRouteClassIsPluggable(object):
         routes2 = RouteCollection()
         routes2.include("/incl", routes)
 
-        assert list(routes2.get_routes("/incl/", GET)) == [
+        assert list(routes2.get_route_traversals("/incl/", GET)) == [
             tms.InstanceOf(RouteTraversal, route=tms.InstanceOf(self.CustomRoute))
         ]
 
@@ -1022,14 +1027,14 @@ class TestRouteTraversal(object):
     routes.delegate("/<i:int>", lambda i, r=inner: r, dynamic=True, name="a")
 
     def test_it_reconstructs_the_path(self):
-        traversal = next(self.routes.get_routes("/1/2/3", GET))
+        traversal = next(self.routes.get_route_traversals("/1/2/3", GET))
 
         # Do we get the original path back?
         assert traversal.build_path() == "/1/2/3"
 
     def test_it_modifies_the_path(self):
 
-        traversal = next(self.routes.get_routes("/1/2/3", GET))
+        traversal = next(self.routes.get_route_traversals("/1/2/3", GET))
 
         # Modify the traversal and check we get a modified path back
         assert traversal.replace("a", {"i": 0}).build_path() == "/0/2/3"
@@ -1049,7 +1054,7 @@ class TestRouteTraversal(object):
         assert traversal.replace("a") == traversal
 
     def test_replace_raises_routenotfound(self):
-        traversal = next(self.routes.get_routes("/1/2/3", GET))
+        traversal = next(self.routes.get_route_traversals("/1/2/3", GET))
         with pytest.raises(RouteNotFound):
             traversal.replace("x")
 
@@ -1091,13 +1096,13 @@ class TestRouteCache(object):
         )
 
         # Prime the cache
-        list(rc.get_routes("/bacon", GET))
+        list(rc.get_route_traversals("/bacon", GET))
 
         with pytest.raises(CustomException):
-            list(rc.get_routes("/eggs/x", GET))
+            list(rc.get_route_traversals("/eggs/x", GET))
 
         with pytest.raises(CustomException):
-            list(rc.get_routes("/eggs/x", GET))
+            list(rc.get_route_traversals("/eggs/x", GET))
 
         # Check a subsequent call to get_routes doesn't hang onto the exception
-        list(rc.get_routes("/bacon", GET))
+        list(rc.get_route_traversals("/bacon", GET))
