@@ -8,6 +8,7 @@ from fresco.routeargs import GetArg, routearg
 from fresco.subrequests import subrequest, subrequest_raw, subrequest_bytes
 
 from unittest.mock import Mock
+import typing as t
 import pytest
 
 
@@ -87,6 +88,15 @@ class TestSubRequest(object):
         with app.requestcontext():
             assert subrequest("named view") == "foo"
 
+    def test_viewspec_can_be_a_path(self):
+        def view():
+            return Response("foo")
+
+        app = FrescoApp()
+        app.route("/view", GET, view, name="named view")
+        with app.requestcontext():
+            assert subrequest("/view") == "foo"
+
     def test_viewspec_uses_routeargs(self):
         def view(a, b):
             return Response(["*" + a + b + "*"])
@@ -185,3 +195,22 @@ class TestSubRequest(object):
             )
             assert subreq_environ["PATH_INFO"] == "/view"
             assert subreq_environ["QUERY_STRING"] == "test"
+
+    def test_it_merges_custom_environ_keys(self):
+
+        subreq_environ: t.Optional[dict] = None
+
+        def view():
+            nonlocal subreq_environ
+            subreq_environ = context.request.environ
+            return Response()
+
+        app = FrescoApp()
+        app.route("/view", GET, view)
+
+        with app.requestcontext("/xyzzy") as c:
+            original_environ = c.request.environ
+            subrequest(view, _full=True, _env={"hey.there": True})
+            assert subreq_environ is not None
+            assert "hey.there" in subreq_environ
+            assert "hey.there" not in original_environ
